# CPU type
set cpu_type TMS470R1B

# Flash support
set flash_types { 0 1 2 3 }

# target-side code of flash loader
set FlashLoadSuppCode $mypath/trgcode/flash470r1b.out

# target is big endian by documentation, but driver
# corrects memory values automatically
# 2 - correction only of write data. Read data are corrected by driver
set TargetBigEndian 0

# PC register name
set pc_name PC

# CPU minimal word width (0 - 8 bit, 1 - 16, 2 - 32)
#
set word_width 0


##############################################################
# base address of I2C controllers
# +2 due to big endian target and (uint16) access
set i2c1_base 0xFFF7D802
set i2c2_base 0xFFF7D902
set i2c3_base 0xFFF7DA02
set i2c4_base 0xFFF7DB02
set i2c5_base 0xFFF7D502

##############################################################
# base address of SPI controllers
set spi1_base 0xFFF7F800
set spi2_base 0xFFF7D400


##############################################################
# base address of internal flash controller
#
set internal_flash_ctrlr_base 0xFFE88000

# start address of flash itself in CPU's address space
#
set internal_flash_base 0x10000000

# parameters of Internal Flash
# TMS470R1B1 contains two banks with 8 sectors in each bank
# sectors are uniform, 64 Kbyte size

set internal_flash_sectors  {
  { 65536 0 }
  { 65536 0 }
  { 65536 0 }
  { 65536 0 }
  { 65536 0 }
  { 65536 0 }
  { 65536 0 }
  { 65536 0 }
  { 65536 1 }
  { 65536 1 }
  { 65536 1 }
  { 65536 1 }
  { 65536 1 }
  { 65536 1 }
  { 65536 1 }
  { 65536 1 } }

# if set, flash tool checks for bits, masked by this variable value
# in start address and data length are zero.
#
set internal_flash_alignment 3

# Password base address in internal flash
# For R1B1: (end of 1'st sector - 0x20)
set pswd_base [expr [lindex [lindex $internal_flash_sectors 0] 0] - 0x20]

###########################################################################
# CPU-specific initialization
###########################################################################
proc CPUSpecificInit { dev } {
                  
  upvar 1 flash_type flash_type
  upvar 1 internal_flash_ctrlr_base internal_flash_ctrlr_base
  upvar 1 internal_flash_base internal_flash_base
  upvar 1 pswd_base pswd_base
  upvar 1 msm_password msm_password

  puts "Configuring memory map"

  # Deactivate memory MAP
  PutLong $dev 0xFFFFFE04 0 0
  PutLong $dev 0xFFFFFE00 0 0
  PutLong $dev 0xFFFFFE08 0 0
  PutLong $dev 0xFFFFFE0C 0 0
  PutLong $dev 0xFFFFFE10 0 0
  PutLong $dev 0xFFFFFE14 0 0
  PutLong $dev 0xFFFFFE18 0 0
  PutLong $dev 0xFFFFFE1C 0 0

  # Place FLASH to $internal_flash_base address
  PutLong $dev 0xFFFFFE00 0 [expr $internal_flash_base >> 16]
  PutLong $dev 0xFFFFFE04 0 [expr ($internal_flash_base & 0xFC00) | 0x000000B0]

  # Place RAM to 0x00010000 address
  PutLong $dev 0xFFFFFE10 0 0x00000001
  PutLong $dev 0xFFFFFE14 0 0x00000070

  # Activate memory MAP
  PutLong $dev 0xFFFFFE04 0 [expr ($internal_flash_base & 0xFC00) | 0x000001B0]

  # Unlock MSM
  # CPU is configured with FLASH start address 0x10000000
  #

  puts "Unlocking MSM"

  # Force MSM to secure mode
  PutLong $dev 0xFFFFF724 0 0x80000000

  ReadLong $dev [expr $internal_flash_base + $pswd_base + 0x00] 0
  ReadLong $dev [expr $internal_flash_base + $pswd_base + 0x04] 0
  ReadLong $dev [expr $internal_flash_base + $pswd_base + 0x08] 0
  ReadLong $dev [expr $internal_flash_base + $pswd_base + 0x0C] 0

  #
  # Put correct MSM password instead FFFF's here, if any.
  #

  PutLong $dev 0xFFFFF700 0 [lindex $msm_password 0]
  PutLong $dev 0xFFFFF704 0 [lindex $msm_password 1]  
  PutLong $dev 0xFFFFF708 0 [lindex $msm_password 2]
  PutLong $dev 0xFFFFF70C 0 [lindex $msm_password 3]

  puts "Disabling illegal address resets"
  # Disable illegal address reset
  # SYSECR
  PutLong $dev 0xFFFFFFE0 0 0x00004007

  puts "Enabling peripheral clock and access to flash controller"

  # Enable peripheral clock
  PutLong $dev 0xFFFFFD30 0 0x00000001

  # Enable write to flash controllers registers
  # And set ZPLL to fOut = Fin
  # GLBCTRL
  set rval [ReadLong $dev 0xFFFFFFDC 0]
  PutLong $dev 0xFFFFFFDC 0 [expr ($rval & 0xFFFF3FE0) | 0x1B]

  # Reset all bits in FMREGOPT - disable OTP block & pipeline mode
  PutLong $dev [expr $internal_flash_ctrlr_base + 0x1C00] 0 0

}



